@@ -1,7 +1,7 @@
 package Test::Some;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: test a subset of tests
-$Test::Some::VERSION = '0.1.0';
+$Test::Some::VERSION = '0.2.0';
 
 use 5.10.0;
 
@@ -26,21 +26,20 @@ sub import {
     _groom_filter($caller,$_) for @filters;
 
     eval <<"END_EVAL";
-        package $caller; 
-        use Test::More;
-        use Class::Method::Modifiers;
+        package $caller;
 
-        # needs to be after Test::More put
-        # its own 'subtest' in there,
-        # hence the INIT
+        # delaying stuff to INIT 
+        # because Test::Some can be loaded before Test::More
         INIT {
-            around subtest => sub {
-                Test::Some::_subtest(\@_);
-            }
+            my \$original_subtest = $caller->can('subtest')
+                or die "no function 'subtest' found in package $caller. Forgot to import Test::More?";
+
+            no warnings 'redefine';
+            no strict 'refs';
+            *{"${caller}::subtest"} = sub { Test::Some::_subtest( \$original_subtest, \@_ ) };
         }
 END_EVAL
 
-    die $@ if $@;
 
 }
 
@@ -96,7 +95,7 @@ sub _should_be_skipped {
 
 sub _subtest {
     my( $orig, $name, $code, @tags ) = @_;
-    my $caller = caller 3;
+    my $caller = caller;
 
     if( _should_be_skipped($caller,$name,@tags) ) {
         return if $BYPASS;
@@ -123,7 +122,7 @@ Test::Some - test a subset of tests
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 SYNOPSIS
 
